==> cssadmin_1.0.0.tar.gz: cssadmin/class/mycssadmin_utility.class.php <==
<?php
// mycssadmin ver 1.0.0
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/dev>                       //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/ 
// ľܸƤӽФ줿exit
//*****************************************************************************/ 
if( ! defined( 'XOOPS_ROOT_PATH' ) ) exit ;

if( ! class_exists( 'CssadminUtility' ) ) {

class CssadminUtility {

	/**
	 * CssadminUtility
	 * 
	 * @param void
	 * @return void
	 */
	function CssadminUtility() {
	}


	function getBlockArray() {
		// 
		global $xoopsModule,$xoopsUser,$xoopsConfig;
		$xoopsblock = new XoopsBlock();
		$block_arr = array();

		if (is_object($xoopsUser)) {
			if (!empty($xoopsModule)) {
				// set page title
				if (preg_match("/index\.php$/i", xoops_getenv('PHP_SELF')) && $xoopsConfig['startpage'] == $xoopsModule->getVar('dirname')) {
					$block_arr =& $xoopsblock->getAllByGroupModule($xoopsUser->getGroups(), $xoopsModule->getVar('mid'), true, XOOPS_BLOCK_VISIBLE);
				} else {
					$block_arr =& $xoopsblock->getAllByGroupModule($xoopsUser->getGroups(), $xoopsModule->getVar('mid'), false, XOOPS_BLOCK_VISIBLE);
				}
			} else {
				if (!empty($xoopsOption['show_cblock'])) {
					$block_arr =& $xoopsblock->getAllByGroupModule($xoopsUser->getGroups(), 0, true, XOOPS_BLOCK_VISIBLE);
				} else {
					$block_arr =& $xoopsblock->getAllByGroupModule($xoopsUser->getGroups(), 0, false, XOOPS_BLOCK_VISIBLE);
				}
			}
		} else {
			if (!empty($xoopsModule)) {
				// set page title
				if (preg_match("/index\.php$/i", xoops_getenv('PHP_SELF')) && $xoopsConfig['startpage'] == $xoopsModule->getVar('dirname')) {
					$block_arr =& $xoopsblock->getAllByGroupModule(XOOPS_GROUP_ANONYMOUS, $xoopsModule->getVar('mid'), true, XOOPS_BLOCK_VISIBLE);
				} else {
					$block_arr =& $xoopsblock->getAllByGroupModule(XOOPS_GROUP_ANONYMOUS, $xoopsModule->getVar('mid'), false, XOOPS_BLOCK_VISIBLE);
				}
			} else {
				if (!empty($xoopsOption['show_cblock'])) {
					$block_arr =& $xoopsblock->getAllByGroupModule(XOOPS_GROUP_ANONYMOUS, 0, true, XOOPS_BLOCK_VISIBLE);
				} else {
					$block_arr =& $xoopsblock->getAllByGroupModule(XOOPS_GROUP_ANONYMOUS, 0, false, XOOPS_BLOCK_VISIBLE);
				}
			}
		}
		return $block_arr;
	}


	function getCssadminHeader( $block_mod_dirname, $buf ) {
		// 
		global $xoopsTpl;
		$xoopsDB =& Database::getInstance();
		$cssadmin_header = '';
		$isCssadmin = ( $block_mod_dirname === 'cssadmin' ) ? true : false;
		// ɽβ̤ɤΥ⥸塼β̤
		$module_dirname = is_object($xoopsTpl) ? $xoopsTpl->get_template_vars( 'xoops_dirname' ) : '';
		if ( !empty($module_dirname) ) {
			// Υ֥åcssadmin⥸塼Υ֥åǡ
			// class/cssadmin_modules.class.php¸ߤƤ硢
			// ⥸塼ɳդCSSե
			if ( $isCssadmin && 
				 file_exists(dirname(__FILE__) .'/cssadmin_modules.class.php') ) {
				include( dirname(__FILE__) .'/cssadmin_modules.class.php' );
				$css = $CssadminModules->getModuleCssHeader( $module_dirname );
				// ⥸塼ɳդCSSե뤬¸ߤ硢link
				if ( !empty($css) ) {
					$module_header = '<link rel="stylesheet" type="text/css" media="screen" href="';
					$module_header .= XOOPS_URL .'/modules/' .$module_dirname .'/css/';
					$module_header .= $css .'" />';
					// link̤ϤǤСcssadminΥإåɲ
					if ( ! strstr($buf, $module_header) ) {
						$cssadmin_header .= $module_header ."\n";
					}
				}
			}
		}
		// ɽ֥åμ
		global $block_arr;
		$bid_list = array();
		if ( empty($block_arr) ) {
			$block_arr = $this->getBlockArray();
		}
		foreach( $block_arr as $key=> $block ) {
			// ֥åcssadmin⥸塼Υ֥åǤ뤫
			// functionƤӽФ֥åǤäϡcssbid˳Ǽ
			if ( $isCssadmin || 
				 $block_mod_dirname === $block->vars['dirname']['value'] ) {
				$bid_list[] = intval( $block->vars['bid']['value'] );
			}
		}
		if ( ! empty($bid_list) ) {
			$bids = implode( ',', $bid_list );
			// ֥åɳդCSS¸ߤ뤫ǧ
			$cssadmin_blocks = $xoopsDB->prefix( 'cssadmin_blocks' );
			$modules = $xoopsDB->prefix( 'modules' );
			$sql = "SELECT modules.dirname, cssadmin_blocks.css FROM $cssadmin_blocks cssadmin_blocks";
			$sql .= " LEFT JOIN $modules modules ON modules.mid = cssadmin_blocks.mid";
			$sql .= " WHERE bid IN ( $bids )";
			$result = $xoopsDB->query( $sql );
			if ( $myrow = $xoopsDB->fetchArray($result) ) {
				// ֥åCSS꤬硢֥åإå򥻥åȤ
				do {
					$block_dirname = urlencode( htmlspecialchars($myrow['dirname'], ENT_QUOTES) );
					$block_css = urlencode( htmlspecialchars($myrow['css'], ENT_QUOTES) );
					$block_header = '<link rel="stylesheet" type="text/css" media="screen" href="';
					// $block_dirnameǤХ⥸塼֥åCSS
					if ( ! empty($block_dirname) ) {
						$block_header .= XOOPS_URL .'/modules/' .$block_dirname .'/css/';
					// $block_dirname¸ߤʤХ֥åCSS
					} else {
						$block_header .= XOOPS_URL .'/css/';
					}
					$block_header .= $block_css .'" />';
					// link̤ϤǤСcssadminΥإåɲ
					if ( (! strstr($cssadmin_header, $block_header)) &&
						 (! strstr($buf, $block_header)) ) {
						$cssadmin_header .= $block_header ."\n";
					}
				} while ( $myrow = $xoopsDB->fetchArray($result) );
			}
		}
		if ( !empty($cssadmin_header) ) {
			$buf = str_replace( '</head>', 
			 					$cssadmin_header .'</head>', 
								$buf );
		}
		return $buf;
	}

// end of class
}

}

?>

==> cssadmin_1.0.3.tar.gz: cssadmin/class/mycssadmin_utility.class.php <==
<?php
// mycssadmin ver 1.0.3
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/dev>                       //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/ 
// ľܸƤӽФ줿exit
//*****************************************************************************/ 
if( ! defined( 'XOOPS_ROOT_PATH' ) ) exit ;

if( ! class_exists( 'CssadminUtility' ) ) {

class CssadminUtility {

	/**
	 * CssadminUtility
	 * 
	 * @param void
	 * @return void
	 */
	function CssadminUtility() {
	}


	function getBlockArray() {
		// 
		global $xoopsModule,$xoopsUser,$xoopsConfig;
		$xoopsblock = new XoopsBlock();
		$block_arr = array();

		if (is_object($xoopsUser)) {
			if (!empty($xoopsModule)) {
				// set page title
				if (preg_match("/index\.php$/i", xoops_getenv('PHP_SELF')) && $xoopsConfig['startpage'] == $xoopsModule->getVar('dirname')) {
					$block_arr =& $xoopsblock->getAllByGroupModule($xoopsUser->getGroups(), $xoopsModule->getVar('mid'), true, XOOPS_BLOCK_VISIBLE);
				} else {
					$block_arr =& $xoopsblock->getAllByGroupModule($xoopsUser->getGroups(), $xoopsModule->getVar('mid'), false, XOOPS_BLOCK_VISIBLE);
				}
			} else {
				if (!empty($xoopsOption['show_cblock'])) {
					$block_arr =& $xoopsblock->getAllByGroupModule($xoopsUser->getGroups(), 0, true, XOOPS_BLOCK_VISIBLE);
				} else {
					$block_arr =& $xoopsblock->getAllByGroupModule($xoopsUser->getGroups(), 0, false, XOOPS_BLOCK_VISIBLE);
				}
			}
		} else {
			if (!empty($xoopsModule)) {
				// set page title
				if (preg_match("/index\.php$/i", xoops_getenv('PHP_SELF')) && $xoopsConfig['startpage'] == $xoopsModule->getVar('dirname')) {
					$block_arr =& $xoopsblock->getAllByGroupModule(XOOPS_GROUP_ANONYMOUS, $xoopsModule->getVar('mid'), true, XOOPS_BLOCK_VISIBLE);
				} else {
					$block_arr =& $xoopsblock->getAllByGroupModule(XOOPS_GROUP_ANONYMOUS, $xoopsModule->getVar('mid'), false, XOOPS_BLOCK_VISIBLE);
				}
			} else {
				if (!empty($xoopsOption['show_cblock'])) {
					$block_arr =& $xoopsblock->getAllByGroupModule(XOOPS_GROUP_ANONYMOUS, 0, true, XOOPS_BLOCK_VISIBLE);
				} else {
					$block_arr =& $xoopsblock->getAllByGroupModule(XOOPS_GROUP_ANONYMOUS, 0, false, XOOPS_BLOCK_VISIBLE);
				}
			}
		}
		return $block_arr;
	}


	function getCssadminHeader( $block_mod_dirname, $buf ) {
		// 
		global $xoopsTpl;
		$xoopsDB =& Database::getInstance();
		$cssadmin_header = '';
		$isCssadmin = ( $block_mod_dirname === 'cssadmin' ) ? true : false;
		// ɽβ̤ɤΥ⥸塼β̤
		$module_dirname = is_object($xoopsTpl) ? $xoopsTpl->get_template_vars( 'xoops_dirname' ) : '';
		if ( !empty($module_dirname) ) {
			// Υ֥åcssadmin⥸塼Υ֥åǡ
			// class/cssadmin_modules.class.php¸ߤƤ硢
			// ⥸塼ɳդCSSե
			if ( $isCssadmin && 
				 file_exists(dirname(__FILE__) .'/cssadmin_modules.class.php') ) {
				include( dirname(__FILE__) .'/cssadmin_modules.class.php' );
				$css = $CssadminModules->getModuleCssHeader( $module_dirname );
				// ⥸塼ɳդCSSե뤬¸ߤ硢link
				if ( !empty($css) ) {
					$module_header = '<link rel="stylesheet" type="text/css" media="all" href="';
					$module_header .= XOOPS_URL .'/modules/' .$module_dirname .'/css/';
					$module_header .= $css .'" />';
					// link̤ϤǤСcssadminΥإåɲ
					if ( ! strstr($buf, $module_header) ) {
						$cssadmin_header .= $module_header ."\n";
					}
				}
			}
		}
		// ɽ֥åμ
		global $block_arr;
		$bid_list = array();
		if ( empty($block_arr) ) {
			$block_arr = $this->getBlockArray();
		}
		foreach( $block_arr as $key=> $block ) {
			// ֥åcssadmin⥸塼Υ֥åǤ뤫
			// functionƤӽФ֥åǤäϡcssbid˳Ǽ
			if ( $isCssadmin || 
				 $block_mod_dirname === $block->vars['dirname']['value'] ) {
				$bid_list[] = intval( $block->vars['bid']['value'] );
			}
		}
		if ( ! empty($bid_list) ) {
			$bids = implode( ',', $bid_list );
			// ֥åɳդCSS¸ߤ뤫ǧ
			$cssadmin_blocks = $xoopsDB->prefix( 'cssadmin_blocks' );
			$modules = $xoopsDB->prefix( 'modules' );
			$sql = "SELECT modules.dirname, cssadmin_blocks.css FROM $cssadmin_blocks cssadmin_blocks";
			$sql .= " LEFT JOIN $modules modules ON modules.mid = cssadmin_blocks.mid";
			$sql .= " WHERE bid IN ( $bids )";
			$result = $xoopsDB->query( $sql );
			if ( $myrow = $xoopsDB->fetchArray($result) ) {
				// ֥åCSS꤬硢֥åإå򥻥åȤ
				do {
					$block_dirname = urlencode( htmlspecialchars($myrow['dirname'], ENT_QUOTES) );
					$block_css = urlencode( htmlspecialchars($myrow['css'], ENT_QUOTES) );
					$block_header = '<link rel="stylesheet" type="text/css" media="all" href="';
					// $block_dirnameǤХ⥸塼֥åCSS
					if ( ! empty($block_dirname) ) {
						$block_header .= XOOPS_URL .'/modules/' .$block_dirname .'/css/';
					// $block_dirname¸ߤʤХ֥åCSS
					} else {
						$block_header .= XOOPS_URL .'/css/';
					}
					$block_header .= $block_css .'" />';
					// link̤ϤǤСcssadminΥإåɲ
					if ( (! strstr($cssadmin_header, $block_header)) &&
						 (! strstr($buf, $block_header)) ) {
						$cssadmin_header .= $block_header ."\n";
					}
				} while ( $myrow = $xoopsDB->fetchArray($result) );
			}
		}
		if ( !empty($cssadmin_header) ) {
			$buf = str_replace( '</head>', 
			 					$cssadmin_header .'</head>', 
								$buf );
		}
		return $buf;
	}

// end of class
}

}

?>
